@@ -1917,7 +1917,7 @@ class CloudRedisClient(metaclass=CloudRedisClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "CloudRedisClient":
         return self
 
     def __exit__(self, type, value, traceback):
